summaryrefslogtreecommitdiffhomepage
path: root/dev/lib/logic
diff options
context:
space:
mode:
Diffstat (limited to 'dev/lib/logic')
-rw-r--r--dev/lib/logic/equiv.hpp4
-rw-r--r--dev/lib/logic/math.hpp4
-rw-r--r--dev/lib/logic/opt.hpp10
3 files changed, 9 insertions, 9 deletions
diff --git a/dev/lib/logic/equiv.hpp b/dev/lib/logic/equiv.hpp
index 05d0f53..5b022f8 100644
--- a/dev/lib/logic/equiv.hpp
+++ b/dev/lib/logic/equiv.hpp
@@ -8,7 +8,7 @@
#pragma once
/// @brief OCL equivalence namespace.
-namespace scl::equiv
+namespace ocl::equiv
{
template <typename T>
struct basic_hash_trait
@@ -101,4 +101,4 @@ namespace scl::equiv
return left_ / right_ == 1;
}
};
-} // namespace scl::equiv
+} // namespace ocl::equiv
diff --git a/dev/lib/logic/opt.hpp b/dev/lib/logic/opt.hpp
index 4ce999c..137460c 100644
--- a/dev/lib/logic/opt.hpp
+++ b/dev/lib/logic/opt.hpp
@@ -4,13 +4,13 @@
* Copyright 2023-2025, Amlal El Mahrouss
*/
-#ifndef _SCL_OPT_HPP
-#define _SCL_OPT_HPP
+#ifndef _OCL_OPT_HPP
+#define _OCL_OPT_HPP
#include <lib/except/error.hpp>
#include <utility>
-namespace scl
+namespace ocl
{
enum class return_type
{
@@ -129,6 +129,6 @@ namespace scl
{
return return_type::err;
}
-} // namespace scl
+} // namespace ocl
-#endif /* ifndef _SCL_OPT_HPP */
+#endif /* ifndef _OCL_OPT_HPP */
diff --git a/dev/lib/logic/math.hpp b/dev/lib/logic/math.hpp
index 2d00595..e796eae 100644
--- a/dev/lib/logic/math.hpp
+++ b/dev/lib/logic/math.hpp
@@ -9,7 +9,7 @@
#include <cmath>
-namespace scl
+namespace ocl
{
template <std::size_t T>
struct is_non_boolean_integer final
@@ -32,4 +32,4 @@ namespace scl
constexpr inline auto not_a_number = NAN;
constexpr inline auto positive_infinity = INFINITY;
constexpr inline auto negative_infinity = -positive_infinity;
-} // namespace scl \ No newline at end of file
+} // namespace ocl \ No newline at end of file